@@ -1,7 +1,13 @@
 #-------------------------------------------------------------------------------
 #       Utils for Baseline calculation
 #-------------------------------------------------------------------------------
+import pandas as pd
+from .read.read_data import *
+from .read.utils.sw import *
 
+### Global Variables ###
+GMT_DATEFORMAT = '%Y-%m-%dT%H:%M'
+MATLAB_DATEFORMAT = '%Y-%m-%d %H:%M'
 
 def baseline_calc_amean ( SSP1, SSP2, BSL_range, TAT):
     """ Calculates measured baseline lengths (arithmetic mean sound speed).
@@ -388,3 +394,67 @@ def calc_hmssp_recp_v(bsl):
 
     return(bsl)
 # end def calc_hmssp_recp_v(bsl):
+
+def calc_prs_diff(PRS1,PRS2):
+    """Calculates vertical pressure differences by subtracting pressure from each other.
+
+    It needs:
+        bsl ... pandas.Dataframe with ID of beacon 1 ('ID'), ID of beacon 2
+        ('range_ID'), pressure od beacon 1 ('prs1'), pressure data os beacon 2
+         ('prs2').
+         
+    It returns:
+        bsl ... pandas.Dataframe with ID of beacon 1 ('ID'), ID of beacon 2
+        ('range_ID'), pressure od beacon 1 ('prs1'), pressure data os beacon 2
+         ('prs2') and the pressure difference of beacon 1 and beacon 2 ('prs_diff')
+    
+    
+"""
+    
+        
+    PRS1_corr = (pd.DataFrame(PRS1[10::]) - pd.DataFrame(PRS1[10::]).mean())/pd.DataFrame(PRS1[10::]).std()
+    PRS2_corr = (pd.DataFrame(PRS2[10::]) - pd.DataFrame(PRS2[10::]).mean())/pd.DataFrame(PRS2[10::]).std()
+    
+    # Reindex of PRS 1 to substract the pressure
+    #df_prs1_newindex = PRS1_corr.reindex(PRS2_corr.index).append(PRS1_corr).sort_index() # deprecated
+    df_prs1_newindex = PRS1_corr.reindex(PRS2_corr.index)
+    df_prs1_newindex = pd.concat([df_prs1_newindex,PRS1_corr]).sort_index()
+    
+    
+
+    # Interpolate the prs data to fit the new index
+    prs_interpolate = df_prs1_newindex.interpolate(method ='slinear').rename(columns={"prs1": "prs2"}).drop_duplicates().dropna()
+        
+    PRS_DIFF = PRS2_corr.sub(prs_interpolate).rename(columns={"prs2": "prs_diff"}).drop_duplicates().dropna()
+    
+    return(PRS_DIFF)
+    
+def calc_sv_hrt(beacon,pathname=None,SAL=None,writefile=True,dateformat=None):
+
+    if pathname is None:
+        pathname = ''
+        
+    if pathname is None:
+        SAL = 32
+        
+    if dateformat is None:
+        dateformat = GMT_DATEFORMAT
+        
+    if dateformat is 'MATLAB_DATEFORMAT':
+        dateformat = MATLAB_DATEFORMAT
+        
+    df_prs = read_data(beacon,'prs',pathname=pathname)
+    df_hrt = read_data(beacon,'hrt',pathname=pathname)
+    
+    df = pd.concat([df_hrt, df_prs ], axis=1)
+    
+    df_wilson = sv_wilson(df,SAL).dropna()
+    df_wilson.index.name = 'date'
+    
+    if writefile:
+        df_wilson['sv_hrt'].to_csv(str(beacon) +'-'+ 'SV_HRT' + '.dat',sep='\t', header=True, date_format=dateformat)
+        df_sv_hrt = read_data(str(beacon),'SV_HRT')
+        df_sv_hrt = df_sv_hrt.reset_index().drop_duplicates(subset='date').set_index('date')
+        df_sv_hrt.to_csv(str(beacon) +'-'+ 'SV_HRT'+'.dat',sep='\t', header=True, date_format=dateformat)
+        
+    return(df_wilson)
